#ifndef GAMEINFO_H
#define GAMEINFO_H

/*!
 *@file GameInfo.h
 *@author hxcan <caihuosheng@gmail.com>
 *@brief 表示游戏信息。
 */

#include "Xy_global.h"
#include "LlPreCompile.h" //QUrl
#include "GameType.h" //GameType


/*!
 * \brief The GameInfo class 这个类表示一个游戏的信息。
 */
class LANIMESHARED_EXPORT GameInfo:public QObject
{
    Q_OBJECT

public:
    enum InputType
    {
        Text=1, //!<明文。
        Password=2 //!<密码。
    }; //enum InputType

    void requestConnectPhone(QString sourceIp); //!<请求连接到手机。
    InputType parseInputType(QString inputType); //!<解析输入类型枚举。
    void setInputTypeForIp(QString inputType,QString sourceIp); //!<设置这个IP对应的输入类型。
    static GameInfo * sharedInstance(); //!<获取共享实例。
    void SetGameType(GameType::GameType GmTp2St); //!<设置游戏类型。
    void SetReleaseNumber(quint32 RlsNmbr2St); //!<设置发布号。
    void SetWebGameUrl(QUrl WbGmUrl2St); //!<设置网页游戏的入口URL。
    QUrl GetWebGameUrl(); //!<返回网页游戏的入口URL。
    GameType::GameType GetGameType(); //!<获取游戏类型。
    quint32 GetReleaseNumber(); //!<返回发布号。
    bool IsProgramAbsolute(); //!<查询，主程序是否是绝对路径的。
    void SetProgramAbsolute(bool IsAbslt); //!<设置主程序是否为绝对路径的。
    void SetVersion(quint16 VersionDate); //!<设置版本号。
    void SetName(QString AddGmDlgGetName); //!<设置游戏名字。
    QString GetProgramPath(); //!<获取主程序路径。
    QString GetName(); //!<获取游戏名字。
    void SetProgramPath(QString AddGmDlgGetProgramPath); //!<设置主程序路径。
    void SetExtraUrl2(QUrl AddGmDlgGetExtraUrl2); //!<设置额外URL2.
    void SetExtraUrl1(QUrl AddGmDlgGetExtraUrl1); //!<设置额外URL1.
    QUrl GetExtraUrl2(); //!<获取额外URL2.
    QUrl GetExtraUrl1(); //!<获取额外URL1.

signals:
    void inputTypeChanged(InputType inputType,QString phoneIp); //!<输入类型发生变化。
    void shouldConnectPhone (QString sourceIp); //!<应当连接手机。


private:
    GameInfo(); //!<默认构造函数。
    static GameInfo * theSharedInstance; //!<共享实例。
    QUrl WbGmUrl; //!<网页游戏入口的URL。
    GameType::GameType GmTp; //!<游戏类型。
    quint32 RlsNmbr; //!<发布号。
    bool ProgramAbsolute; //!<信息，主程序是否是绝对路径的。
    quint16 Version; //!<版本号。
    QString Name; //!<游戏的名字。
    QUrl ExtraUrl1; //!<额外URL1.
    QUrl ExtraUrl2; //!<额外URL2.
    QString MainExePath; //!<安装之后的主程序路径。
};

#endif // GAMEINFO_H
